import {WebClient} from "../../utils/WebClient";
import {apiUrl, AuthEnum, authUrl} from "../../config/config";
import {ResultDto} from "../../model/ResultDto";
import {AuthDto} from "../../model/auth/dto/AuthDto";
import {CaptchaLoginForm} from "../../model/auth/form/CaptchaLoginForm";
import {SmsLoginForm} from "../../model/auth/form/SmsLoginForm";
import {RegisteredForm} from "../../model/auth/form/RegisteredForm";
import {ForgetPassForm2} from "../../model/auth/form/ForgetPassForm2";
import {ForgetPassForm1} from "../../model/auth/form/ForgetPassForm1";
import {RefreshTokenForm} from "../../model/auth/form/RefreshTokenForm";
import {BindResidentForm} from "../../model/auth/form/BindResidentForm";

// tslint:disable-next-line:no-var-requires
const JsonBigString = require('json-bigint')({"storeAsString": true});

// @ts-ignore
export let AuthApi: AuthInterface.oauth;


AuthApi = {
    /**
     * 账号密码登录
     * @param form
     * @param headers
     */
    captcha: async (form: CaptchaLoginForm, headers: any) => {
        const result: ResultDto<AuthDto> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + authUrl + AuthEnum.TOKEN + "?username=" + form.username +
                "&password=" + form.password +
                "&grant_type=" + form.grant_type +
                "&scope=" + form.scope +
                "&client_id=" + form.client_id +
                "&client_secret=" + form.client_secret,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    refresh: async (form: RefreshTokenForm, headers: any) => {
        const result: ResultDto<AuthDto> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + authUrl + AuthEnum.TOKEN + "?grant_type=" + form.grant_type +
                "&scope=" + form.scope +
                "&client_id=" + form.client_id +
                "&client_secret=" + form.client_secret +
                "&refresh_token=" + form.refresh_token,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    /**
     * 验证码登录
     * @param form
     * @param headers
     */
    sms: async (form: SmsLoginForm, headers: any) => {
        const result: ResultDto<AuthDto> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + authUrl + AuthEnum.TOKEN + "?mobile=" + form.mobile +
                "&code=" + form.code +
                "&grant_type=" + form.grant_type +
                "&scope=" + form.scope +
                "&client_id=" + form.client_id +
                "&client_secret=" + form.client_secret,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    /**
     * 注册
     * @param form
     * @param headers
     */
    registered: async (form: RegisteredForm, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + authUrl + AuthEnum.REGISTERED,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    /**
     * 绑定居民身份
     * @param form
     * @param headers
     */
    bind: async (form: BindResidentForm, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + authUrl + AuthEnum.BIND,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    /**
     * 通过验证码更新密码
     * @param form
     * @param headers
     */
    updatePasswordByCode: async (form: ForgetPassForm2, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + authUrl + AuthEnum.UPDATE_PASSWORD_2,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    /**
     * 通过密码修改密码
     * @param form
     * @param headers
     */
    updatePassword: async (form: ForgetPassForm1, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + authUrl + AuthEnum.UPDATE_PASSWORD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    smsCode: async (form: string, type: number, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + authUrl + AuthEnum.SMS_CODE + "?mobile=" + form + "&type=" + type,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
    logout: async (headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(null, {
            url: apiUrl + authUrl + AuthEnum.LOGOUT,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
};
