import {apiUrl, commonBaseUrl, CommonFoodUrlEnum} from "../../config/config";
import {WebClient} from "../../utils/WebClient";
import {ResponsePageDto} from "../../model/ResponsePageDto";
import {FoodTypeDto} from "../../model/common/food/dto/FoodTypeDto";
import {FoodDataDto} from "../../model/common/food/dto/FoodDataDto";
import {FoodSpecsDto} from "../../model/common/food/dto/FoodSpecsDto";
import {ResultDto} from "../../model/ResultDto";
// tslint:disable-next-line:no-var-requires
const JsonUtils = require('json-bigint')({"storeAsString": true});

export const FoodTypeApi: FoodDefine.FoodType = {

    /**
     * 食物类型管理: 条件查询
     * @param form
     * @param headers
     */
    foodTypeQueryList: async (form, headers: any) => {
        const result: ResultDto<FoodTypeDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_TYPE_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 食物类型管理: 分页条件查询
     * @param form
     * @param headers
     */
    foodTypeQueryPage: async (form,headers: any) => {
        const result: ResultDto<ResponsePageDto<FoodTypeDto>> = JsonUtils.parse(await WebClient.requestDataToJson(form,{
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_TYPE_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 食物类型管理: id查询
     * @param form
     * @param headers
     */
    foodTypeQueryById: async (form,headers: any) => {
        const result: ResultDto<FoodTypeDto> = JsonUtils.parse(await WebClient.requestDataToJson("", {
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_TYPE_QUERY_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    /**
     * 食物类型管理: 新增
     * @param form
     * @param headers
     */
    foodTypeSaveOne: async (form,headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form,{
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_TYPE_SAVE_ONE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 食物类型管理: 修改
     * @param form
     * @param headers
     */
    foodTypeUpdateById: async (form,headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form,{
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_TYPE_UPDATE_BY_ID,
            method: 'POST',
            headers: headers
        }));
        return result;
    }
};

export const FoodDataApi: FoodDefine.FoodData = {

    /**
     * 食物数据管理: 条件查询
     * @param form
     * @param headers
     */
    foodDataQueryList: async (form, headers: any) => {
        const result: ResultDto<FoodDataDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_DATA_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 食物数据管理: 分页条件查询
     * @param form
     * @param headers
     */
    foodDataQueryPage: async (form,headers: any) => {
        const result: ResultDto<ResponsePageDto<FoodDataDto>> = JsonUtils.parse(await WebClient.requestDataToJson(form,{
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_DATA_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 食物数据管理: id查询
     * @param form
     * @param headers
     */
    foodDataQueryById: async (form,headers: any) => {
        const result: ResultDto<FoodDataDto> = JsonUtils.parse(await WebClient.requestDataToJson("", {
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_DATA_QUERY_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    /**
     * 食物数据管理: 新增
     * @param form
     * @param headers
     */
    foodDataSaveFoodDataAndSpecs: async (form,headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form,{
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_DATA_SAVE_FOOD_DATA_SPECS,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 食物数据管理: 修改
     * @param form
     * @param headers
     */
    foodDataUpdateById: async (form,headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form,{
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_DATA_UPDATE_BY_ID,
            method: 'POST',
            headers: headers
        }));
        return result;
    }
};

export const FoodSpecsApi: FoodDefine.FoodSpecs = {

    /**
     * 食物数据管理: 根据食物数据id查询
     * @param form
     * @param headers
     */
    foodSpecsQueryByDataId: async (form, headers: any) => {
        const result: ResultDto<FoodSpecsDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_SPECS_QUERY_BY_DATA_ID,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 食物数据管理: 根据id删除
     * @param form
     * @param headers
     */
    foodSpecsDeleteById: async (form,headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson("",{
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_SPECS_DELETE_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    /**
     * 食物规格管理: 保存
     * @param form
     * @param headers
     */
    foodSpecsSaveList: async (form,headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonFoodUrlEnum.FOOD_SPECS_SAVE_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
};