import {QueryFoodTypeForm} from "../../model/common/food/form/QueryFoodTypeForm";
import {FoodTypeDto} from "../../model/common/food/dto/FoodTypeDto";
import {ResponsePageDto} from "../../model/ResponsePageDto";
import {SaveFoodTypeForm} from "../../model/common/food/form/SaveFoodTypeForm";
import {UpdateFoodTypeForm} from "../../model/common/food/form/UpdateFoodTypeForm";
import {QueryFoodDataForm} from "../../model/common/food/form/QueryFoodDataForm";
import {FoodDataDto} from "../../model/common/food/dto/FoodDataDto";
import {SaveFoodDataForm} from "../../model/common/food/form/SaveFoodDataForm";
import {UpdateFoodDataForm} from "../../model/common/food/form/UpdateFoodDataForm";
import {FoodSpecsDto} from "../../model/common/food/dto/FoodSpecsDto";
import {SaveFoodSpecsForm} from "../../model/common/food/form/SaveFoodSpecsForm";
import {ResultDto} from "../../model/ResultDto";

declare global {
    namespace FoodDefine {

        /**
         * 食物类型管理
         */
        interface FoodType {
            /**
             * 条件查询
             * @param form
             * @param headers
             */
            foodTypeQueryList?: (form: QueryFoodTypeForm, headers: any) => Promise<ResultDto<FoodTypeDto[]>>;

            /**
             * 分页条件查询
             * @param form
             * @param headers
             */
            foodTypeQueryPage?: (form: QueryFoodTypeForm, headers: any) => Promise<ResultDto<ResponsePageDto<FoodTypeDto>>>;

            /**
             * 根据id查询
             * @param form
             * @param headers
             */
            foodTypeQueryById?: (form: string, headers: any) => Promise<ResultDto<FoodTypeDto>>;

            /**
             * 新增
             * @param form
             * @param headers
             */
            foodTypeSaveOne?: (form: SaveFoodTypeForm, headers: any) => Promise<ResultDto<boolean>>;

            /**
             * 修改
             * @param form
             * @param headers
             */
            foodTypeUpdateById?: (form: UpdateFoodTypeForm, headers: any) => Promise<ResultDto<boolean>>;
        }

        /**
         * 食物数据管理
         */
        interface FoodData {
            /**
             * 条件查询
             * @param form
             * @param headers
             */
            foodDataQueryList?: (form: QueryFoodDataForm, headers: any) => Promise<ResultDto<FoodDataDto[]>>;

            /**
             * 分页条件查询
             * @param form
             * @param headers
             */
            foodDataQueryPage?: (form: QueryFoodDataForm, headers: any) => Promise<ResultDto<ResponsePageDto<FoodDataDto>>>;

            /**
             * 根据id查询
             * @param form
             * @param headers
             */
            foodDataQueryById?: (form: string, headers: any) => Promise<ResultDto<FoodDataDto>>;

            /**
             * 新增
             * @param form
             * @param headers
             */
            foodDataSaveFoodDataAndSpecs?: (form: SaveFoodDataForm, headers: any) => Promise<ResultDto<boolean>>;

            /**
             * 修改
             * @param form
             * @param headers
             */
            foodDataUpdateById?: (form: UpdateFoodDataForm, headers: any) => Promise<ResultDto<boolean>>;
        }

        /**
         * 食物规格管理
         */
        interface FoodSpecs {
            /**
             * 根据食物数据ids查询食物数据对应规格列表
             * @param form
             * @param headers
             */
            foodSpecsQueryByDataId?: (form: string[], headers: any) => Promise<ResultDto<FoodSpecsDto[]>>;

            /**
             * 根据id删除食物规格
             * @param form
             * @param headers
             */
            foodSpecsDeleteById?: (form: string, headers: any) => Promise<ResultDto<boolean>>;

            /**
             * 添加食物规格
             * @param form
             * @param headers
             */
            foodSpecsSaveList?: (form: SaveFoodSpecsForm[], headers: any) => Promise<ResultDto<boolean>>;
        }
    }
}
export {};