import {
    apiUrl,
    commonBaseUrl,
    CommonMotionUrlEnum
} from "../../config/config";
import {WebClient} from "../../utils/WebClient";
import {ResponsePageDto} from "../../model/ResponsePageDto";
import {MotionTypeDto} from "../../model/common/Motion/dto/MotionTypeDto";
import {MotionDataDto} from "../../model/common/Motion/dto/MotionDataDto";
import {MotionSpecsDto} from "../../model/common/Motion/dto/MotionSpecsDto";
import {ResultDto} from "../../model/ResultDto";
// tslint:disable-next-line:no-var-requires
const JsonUtils = require('json-bigint')({"storeAsString": true});

export const MotionTypeApi: MotionDefine.MotionType = {

    /**
     * 运动类型管理: 条件查询
     * @param form
     * @param headers
     */
    motionTypeQueryList: async (form, headers: any) => {
        const result: ResultDto<MotionTypeDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_TYPE_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动类型管理: 分页条件查询
     * @param form
     * @param headers
     */
    motionTypeQueryPage: async (form, headers: any) => {
        const result: ResultDto<ResponsePageDto<MotionTypeDto>> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_TYPE_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动类型管理: id查询
     * @param form
     * @param headers
     */
    motionTypeQueryById: async (form, headers: any) => {
        const result: ResultDto<MotionTypeDto> = JsonUtils.parse(await WebClient.requestDataToJson("", {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_TYPE_QUERY_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动类型管理: 新增
     * @param form
     * @param headers
     */
    motionTypeSaveOne: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_TYPE_SAVE_ONE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动类型管理: 修改
     * @param form
     * @param headers
     */
    motionTypeUpdateById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_TYPE_UPDATE_BY_ID,
            method: 'POST',
            headers: headers
        }));
        return result;
    }
};

export const MotionDataApi: MotionDefine.MotionData = {

    /**
     * 运动数据管理: 条件查询
     * @param form
     * @param headers
     */
    motionDataQueryList: async (form, headers: any) => {
        const result: ResultDto<MotionDataDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_DATA_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动数据管理: 分页条件查询
     * @param form
     * @param headers
     */
    motionDataQueryPage: async (form, headers: any) => {
        const result: ResultDto<ResponsePageDto<MotionDataDto>> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_DATA_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动数据管理: id查询
     * @param form
     * @param headers
     */
    motionDataQueryById: async (form, headers: any) => {
        const result: ResultDto<MotionDataDto> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_DATA_QUERY_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动数据管理: ids查询
     * @param form
     * @param headers
     */
    motionDataQueryByIds: async (form, headers: any) => {
        const result: ResultDto<MotionDataDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_DATA_QUERY_BY_IDS,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动数据管理: 新增
     * @param form
     * @param headers
     */
    motionDataSaveMotionDataAndSpecs: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_DATA_SAVE_MOTION_DATA_SPECS,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动数据管理: 修改
     * @param form
     * @param headers
     */
    motionDataUpdateById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_DATA_UPDATE_BY_ID,
            method: 'POST',
            headers: headers
        }));
        return result;
    }
};

export const MotionSpecsApi: MotionDefine.MotionSpecs = {

    /**
     * 运动规格管理: 根据运动数据ids查询
     * @param form
     * @param headers
     */
    motionSpecsQueryByDataId: async (form, headers: any) => {
        const result: ResultDto<MotionSpecsDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_SPECS_QUERY_BY_DATA_ID,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动规格管理: 根据id删除
     * @param form
     * @param headers
     */
    motionSpecsDeleteById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson("", {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_SPECS_DELETE_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    /**
     * 运动规格管理: 保存
     * @param form
     * @param headers
     */
    motionSpecsSaveList: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonMotionUrlEnum.MOTION_SPECS_SAVE_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
};