import {ResponsePageDto} from "../../model/ResponsePageDto";
import {QueryMotionTypeForm} from "../../model/common/motion/form/QueryMotionTypeForm";
import {MotionTypeDto} from "../../model/common/motion/dto/MotionTypeDto";
import {SaveMotionTypeForm} from "../../model/common/motion/form/SaveMotionTypeForm";
import {UpdateMotionTypeForm} from "../../model/common/motion/form/UpdateMotionTypeForm";
import {QueryMotionDataForm} from "../../model/common/motion/form/QueryMotionDataForm";
import {MotionDataDto} from "../../model/common/motion/dto/MotionDataDto";
import {SaveMotionDataForm} from "../../model/common/motion/form/SaveMotionDataForm";
import {UpdateMotionDataForm} from "../../model/common/motion/form/UpdateMotionDataForm";
import {MotionSpecsDto} from "../../model/common/motion/dto/MotionSpecsDto";
import {SaveMotionSpecsForm} from "../../model/common/motion/form/SaveMotionSpecsForm";
import {ResultDto} from "../../model/ResultDto";
import {FoodSpecsDto} from "../../model/common/food/dto/FoodSpecsDto";

declare global {
    namespace MotionDefine {

        /**
         * 运动类型管理
         */
        interface MotionType {
            /**
             * 条件查询
             * @param form
             * @param headers
             */
            motionTypeQueryList?: (form: QueryMotionTypeForm, headers: any) => Promise<ResultDto<MotionTypeDto[]>>;

            /**
             * 分页条件查询
             * @param form
             * @param headers
             */
            motionTypeQueryPage?: (form: QueryMotionTypeForm, headers: any) => Promise<ResultDto<ResponsePageDto<MotionTypeDto>>>;

            /**
             * 根据id查询
             * @param form
             * @param headers
             */
            motionTypeQueryById?: (form: string, headers: any) => Promise<ResultDto<MotionTypeDto>>;

            /**
             * 新增
             * @param form
             * @param headers
             */
            motionTypeSaveOne?: (form: SaveMotionTypeForm, headers: any) => Promise<ResultDto<boolean>>;

            /**
             * 修改
             * @param form
             * @param headers
             */
            motionTypeUpdateById?: (form: UpdateMotionTypeForm, headers: any) => Promise<ResultDto<boolean>>;
        }

        /**
         * 运动数据管理
         */
        interface MotionData {
            /**
             * 条件查询
             * @param form
             * @param headers
             */
            motionDataQueryList?: (form: QueryMotionDataForm, headers: any) => Promise<ResultDto<MotionDataDto[]>>;

            /**
             * 分页条件查询
             * @param form
             * @param headers
             */
            motionDataQueryPage?: (form: QueryMotionDataForm, headers: any) => Promise<ResultDto<ResponsePageDto<MotionDataDto>>>;

            /**
             * 根据id查询
             * @param form
             * @param headers
             */
            motionDataQueryById?: (form: string, headers: any) => Promise<ResultDto<MotionDataDto>>;

            /**
             * 根据id查询
             * @param form
             * @param headers
             */
            motionDataQueryByIds?: (form: string[], headers: any) => Promise<ResultDto<MotionDataDto[]>>;

            /**
             * 新增
             * @param form
             * @param headers
             */
            motionDataSaveMotionDataAndSpecs?: (form: SaveMotionDataForm, headers: any) => Promise<ResultDto<boolean>>;

            /**
             * 修改
             * @param form
             * @param headers
             */
            motionDataUpdateById?: (form: UpdateMotionDataForm, headers: any) => Promise<ResultDto<boolean>>;
        }

        /**
         * 运动规格管理
         */
        interface MotionSpecs {
            /**
             * 根据运动数据ids查询运动数据对应规格列表
             * @param form
             * @param headers
             */
            motionSpecsQueryByDataId?: (form: string[], headers: any) => Promise<ResultDto<MotionSpecsDto[]>>;

            /**
             * 根据id删除运动规格
             * @param form
             * @param headers
             */
            motionSpecsDeleteById?: (form: string, headers: any) => Promise<ResultDto<boolean>>;

            /**
             * 添加运动规格
             * @param form
             * @param headers
             */
            motionSpecsSaveList?: (form: SaveMotionSpecsForm[], headers: any) => Promise<ResultDto<boolean>>;
        }
    }
}
export {};