import {ResultDto} from "../../model/ResultDto";
import {WebClient} from "../../utils/WebClient";
import {RecordMenuDto} from "../../model/common/recordMenu/dto/RecordMenuDto";
import {
    apiUrl,
    commonBaseUrl,
    CommonRecordMenuUrlEnum
} from "../../config/config";
import {ResponsePageDto} from "../../model/ResponsePageDto";
// tslint:disable-next-line:no-var-requires
const JsonUtils = require('json-bigint')({"storeAsString": true});

export const RecordMenuApi: RecordMenuDefine.RecordMenu = {

    /**
     * 记录菜单管理: 条件查询
     * @param form
     * @param headers
     */
    recordMenuQueryList: async (form, headers: any) => {
        const result: ResultDto<RecordMenuDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonRecordMenuUrlEnum.RECORD_MENU_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 记录菜单管理: 分页条件查询
     * @param form
     * @param headers
     */
    recordMenuQueryPage: async (form, headers: any) => {
        const result: ResultDto<ResponsePageDto<RecordMenuDto>> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonRecordMenuUrlEnum.RECORD_MENU_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 记录菜单管理: id查询
     * @param form
     * @param headers
     */
    recordMenuQueryById: async (form, headers: any) => {
        const result: ResultDto<RecordMenuDto> = JsonUtils.parse(await WebClient.requestDataToJson("", {
            url: apiUrl + commonBaseUrl + CommonRecordMenuUrlEnum.RECORD_MENU_QUERY_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    /**
     * 记录菜单管理: 新增
     * @param form
     * @param headers
     */
    recordMenuSaveOne: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonRecordMenuUrlEnum.RECORD_MENU_SAVE_ONE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 记录菜单管理: 修改
     * @param form
     * @param headers
     */
    recordMenuUpdateById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + commonBaseUrl + CommonRecordMenuUrlEnum.RECORD_MENU_UPDATE_BY_ID,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    /**
     * 记录菜单管理: 根据父级code查询
     * @param form
     * @param headers
     */
    recordMenuQueryByParentCode: async (form, headers: any) => {
        const result: ResultDto<RecordMenuDto> = JsonUtils.parse(await WebClient.requestDataToJson("", {
            url: apiUrl + commonBaseUrl + CommonRecordMenuUrlEnum.RECORD_MENU_QUERY_BY_PARENT_CODE + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
};

