import {ResultDto} from "../../model/ResultDto";
import {HospDrugDto} from "../../model/hosp/dto/HospDrugDto";
import {HospTherapyDto} from "../../model/hosp/dto/HospTherapyDto";
import {HospKnowDto} from "../../model/hosp/dto/HospKnowDto";
import {HospMaterialDto} from "../../model/hosp/dto/HospMaterialDto";
import {PageUserHospMateForm} from "../../model/hosp/form/PageUserHospForm";
import {HospKnowTypeDto} from "../../model/hosp/dto/HospKnowTypeDto";

declare global {
    namespace HospUserDefine {
        interface HospUser {


            /**
             * 医院的 药物价格
             * @param hospOrg 医院的机构Id
             * @param headers
             * @param errorCallback
             */
            listDrug?:(hospOrg:string, headers: any,
                       errorCallback?: (message: string) => void)=>
                Promise<ResultDto<HospDrugDto[]>>,

            /**
             * 医院的诊疗价格
             * @param data.hospOrg 医院机构Id 可以传0 ,不可以同时传0
             * @param data.deptId 医院的科室Id 可以传0 ,不可以同时传0
             * @param headers
             * @param errorCallback
             */
            listTherapy?:(data: {hospOrg:string,deptId:string}, headers: any,
                       errorCallback?: (message: string) => void)=>
                Promise<ResultDto<HospTherapyDto[]>>,



            /**
             * 分页查询素材列表
             * @param data
             * @param headers
             * @param errorCallback
             */
            pageMate?:(data:PageUserHospMateForm,headers: any,
                       errorCallback?: (message: string) => void)=>
                Promise<ResultDto<HospMaterialDto>>,

            /**
             * 单个素材详情
             * @param data
             * @param headers
             * @param errorCallback
             */
            mateInfo?:(data:string,headers: any,
                       errorCallback?: (message: string) => void)=>
                Promise<ResultDto<HospMaterialDto>>,
            /**
             * 查询健康知识列表
             * @param knowTypeId 类型Id
             * @param headers
             * @param errorCallback
             */
            listKnow?:(knowTypeId: string, headers: any,
                       errorCallback?: (message: string) => void)=>
                Promise<ResultDto<HospKnowDto[]>>,
            /**
             * 医院的健康知识类型
             * @param data.hospOrg 医院机构Id 可以传0 ,不可以同时传0
             * @param data.deptId 医院的科室Id 可以传0 ,不可以同时传0
             * @param headers
             * @param errorCallback
             */
            listKnowType?:(data: {hospOrg:string,deptId:string}, headers: any,
                       errorCallback?: (message: string) => void)=>
                Promise<ResultDto<HospKnowTypeDto[]>>,

        }
    }
}

export {}