import {ResultDto} from "../../model/ResultDto";
import {WebClient} from "../../utils/WebClient";
import {
    apiUrl,
    recordBaseUrl,
    RecordUrlEnum,
    satisfactionUrl,
    SatisfactionUrlEnum, TeachClassUrl,
    TeachUrl
} from "../../config/config";
import {RecordDto} from "../../model/record/dto/RecordDto";
import {ResponsePageDto} from "../../model/ResponsePageDto";
import {RecordStatisticsDto} from "../../model/record/dto/RecordStatisticsDto";
import {UserRecordStateDto} from "../../model/record/dto/UserRecordStateDto";
import List = Mocha.reporters.List;
import {DateRecordDto} from "../../model/record/dto/DateRecordDto";
import {DateCodeRecordDto} from "../../model/record/dto/DateCodeRecordDto";
import {SUCCESS} from "../../config/ResultCodeConfig";
// tslint:disable-next-line:no-var-requires
const JsonUtils = require('json-bigint')({"storeAsString": true});

export const RecordApi: RecordDefine.Record = {

    queryAbnormalNoHandleRecordLog: async function (data, headers,
                                          errorCallback) {
        const resultDto = await WebClient.requestResultDtoPost(
            data,
            recordBaseUrl + RecordUrlEnum.QUERY_ABNORMAL_NO_HANDLE_RECORD_LOG,
            headers
        );

        if (resultDto.code != SUCCESS) {
            if (errorCallback != undefined) {
                errorCallback(resultDto.msg);
            }
        }
        return resultDto;
    },

    querySignStatusByUserIdAndTime: async (userId,signTime, headers: any) => {
        const resultDto = await WebClient.requestResultDtoGet(
            "",
            recordBaseUrl + RecordUrlEnum.QUERY_SIGN_STATUS_BY_USER_ID_AND_TIME + "?userId=" + userId + "&signTime=" + signTime,
            headers
        );
        return resultDto;
    },

    recordQueryList: async (form, headers: any) => {
        const result: ResultDto<RecordDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordQueryPage: async (form, headers: any) => {
        const result: ResultDto<ResponsePageDto<RecordDto>> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_QUERY_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordQueryListByTime: async (form, headers: any) => {
        const result: ResultDto<DateRecordDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_QUERY_LIST_BY_TIME,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordQueryListByTimeType: async (form, headers: any) => {
        const result: ResultDto<DateCodeRecordDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_QUERY_LIST_BY_TIME_TYPE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordQueryById: async (form, headers: any) => {
        const result: ResultDto<RecordDto> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_QUERY_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    recordSaveDiet: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_SAVE_DIET,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordUpdateDiet: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_UPDATE_DIET,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordSaveMotion: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_SAVE_MOTION,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordUpdateMotion: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_UPDATE_MOTION,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordSaveMood: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_SAVE_MOOD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordUpdateMood: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_UPDATE_MOOD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordSaveSleep: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_SAVE_SLEEP,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordUpdateSleep: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_UPDATE_SLEEP,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordSaveBp: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_SAVE_BP,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordUpdateBp: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_UPDATE_BP,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordSaveGlu: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_SAVE_GLU,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordUpdateGlu: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_UPDATE_GLU,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordSavePhysique: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_SAVE_PHYSIQUE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordUpdatePhysique: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_UPDATE_PHYSIQUE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordSaveTemperature: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_SAVE_TEMPERATURE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordUpdateTemperature: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_UPDATE_TEMPERATURE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordDeleteById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_DELETE_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    recordStatistics: async (form, headers: any) => {
        const result: ResultDto<RecordStatisticsDto> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_STATISTICS,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    activeUserTrends: async function (startTime, endTime, orgId, headers: any) {
        return await WebClient.requestResultDtoGet(
            "",
            recordBaseUrl + RecordUrlEnum.ACTIVE_USER_TRENDS + "?startTime=" + startTime + "&endTime=" + endTime + "&orgId=" + orgId,
            headers
        );
    },

    abnormalRecordTrends: async function (startTime, endTime, orgId, headers: any) {
        return await WebClient.requestResultDtoGet(
            "",
            recordBaseUrl + RecordUrlEnum.ABNORMAL_RECORD_TRENDS + "?startTime=" + startTime + "&endTime=" + endTime + "&orgId=" + orgId,
            headers
        );
    },

    doctorWorkBenchCensus: async function (form, headers: any) {
        return await WebClient.requestResultDtoPost(
            form,
            recordBaseUrl + RecordUrlEnum.DOCTOR_WORK_BENCH_CENSUS,
            headers
        );
    },

    doctorWorkBenchNoHandleCensus: async function (startTime, endTime, orgId, headers: any) {
        return await WebClient.requestResultDtoGet(
            "",
            recordBaseUrl + RecordUrlEnum.DOCTOR_WORK_BENCH_NO_HANDLE_CENSUS + "?startTime=" + startTime + "&endTime=" + endTime + "&orgId=" + orgId,
            headers
        );
    },

    recordQueryUserRecordList: async (form, headers: any) => {
        const result: ResultDto<ResponsePageDto<UserRecordStateDto>> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_QUERY_USER_RECORD_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordQueryUserNewRecord: async (form, headers: any) => {
        const result: ResultDto<RecordDto[]> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_QUERY_USER_NEW_RECORD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    recordDeleteRecordDietById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_DELETE_RECORD_DIET_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    recordDeleteRecordMotionById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_DELETE_RECORD_MOTION_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    recordDeleteRecordMoodById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_DELETE_RECORD_MOOD_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    recordDeleteRecordSleepById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_DELETE_RECORD_SLEEP_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    recordDeleteRecordBpById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_DELETE_RECORD_BP_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    recordDeleteRecordGluById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_DELETE_RECORD_GLU_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    recordDeleteRecordPhysiqueById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_DELETE_RECORD_PHYSIQUE_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    recordDeleteRecordTemperatureById: async (form, headers: any) => {
        const result: ResultDto<boolean> = JsonUtils.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + recordBaseUrl + RecordUrlEnum.RECORD_DELETE_RECORD_TEMPERATURE_BY_ID + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
};