import {WebClient} from "../../utils/WebClient";
import {apiUrl, SystemEnum, systemUrl} from "../../config/config";
import {ResultDto} from "../../model/ResultDto";
import {Search} from "../../model/common/form/DictForm";
import {PageDto} from "../../model/PageDto";
import {SysClientEntity} from "../../model/system/entity/SysClientEntity";

// tslint:disable-next-line:no-var-requires
const JsonBigString = require('json-bigint')({"storeAsString": true});

// @ts-ignore
export let ClientApi: ClientInterface.client;


ClientApi = {
    /**
     * 获取分页接口列表
     * @param form
     * @param headers
     */
    list: async (form:Search,  headers: any) => {
        const result: ResultDto<PageDto<SysClientEntity>> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.CLIENT_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    /**
     * 添加系统客户端
     * @param form
     * @param headers
     */
    saveOrUpdate: async (form:SysClientEntity,  headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.CLIENT_SAVE_UPDATE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    /**
     *获取系统客户端信息
     * @param form
     * @param headers
     */
    getClientInfo: async (form:string,  headers: any) => {
        const result: ResultDto<SysClientEntity> = JsonBigString.parse(await WebClient.requestDataToJson(null, {
            url: apiUrl + systemUrl + SystemEnum.CLIENT_INFO+"/"+form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
    /**
     * 批量删除系统客户端
     * @param form 多个用,号隔开
     * @param headers
     */
    delete: async (form:string,  headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.CLIENT_DELETE+"?ids="+form,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    status: async (ids:string,status:string,headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(null, {
            url: apiUrl + systemUrl + SystemEnum.CLIENT_STATUS+"?ids="+ids+"&status="+status,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
};
