import {WebClient} from "../../utils/WebClient";
import {apiUrl, SystemEnum, systemUrl} from "../../config/config";
import {ResultDto} from "../../model/ResultDto";
import {ListSysOrgForm} from "../../model/system/form/ListSysOrgForm";
import {UpdSysOrgForm} from "../../model/system/form/UpdSysOrgForm";
import {SysOrgDto} from "../../model/system/dto/SysOrgDto";
import {PageSysOrgForm} from "../../model/system/form/PageSysOrgForm";
import {PageDto} from "../../model/PageDto";
import {PagePathSysOrgForm} from "../../model/system/form/PagePathSysOrgForm";
import {SysOrgRoleEntity} from "../../model/system/entity/SysOrgRoleEntity";
import {SysOrgRolePageForm} from "../../model/system/form/SysOrgRolePageForm";
import {SaveSysOrgForm} from "../../model/system/form/SaveSysOrgForm";
import {UserOrgRoleDto} from "../../model/system/dto/UserOrgRoleDto";

// tslint:disable-next-line:no-var-requires
const JsonBigString = require('json-bigint')({"storeAsString": true});
export let OrgApi: OrgInterface.sysOrg;
export let OrgRoleApi: OrgInterface.role;

OrgApi = {
    selectByArea: async (form: ListSysOrgForm, headers: any) => {
        const result: ResultDto<SysOrgDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_AREA_CODE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    selectPageByArea: async (form: PageSysOrgForm, headers: any) => {
        const result: ResultDto<PageDto<SysOrgDto>> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_AREA_PAGE_CODE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    selectTreeByArea: async (form: ListSysOrgForm, headers: any) => {
        const result: ResultDto<SysOrgDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_TREE_AREA_CODE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    selectPath: async (form: string, headers: any) => {
        const result: ResultDto<SysOrgDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_PATH + "?path=" + form,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    selectPagePath: async (form: PagePathSysOrgForm, headers: any) => {
        const result: ResultDto<PageDto<SysOrgDto>> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_PAGE_PATH,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    selectTreePath: async (form: string, headers: any) => {
        const result: ResultDto<SysOrgDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_TREE_PATH + "?path=" + form,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    selectOne: async (id: string, headers: any) => {
        const result: ResultDto<SysOrgDto> = JsonBigString.parse(await WebClient.requestDataToJson(id, {
            url: apiUrl + systemUrl + SystemEnum.ORG_INFO_ID + "/" + id,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    insert: async (form: SaveSysOrgForm, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    update: async (form: UpdSysOrgForm, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    delete: async (id: string[], headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(id, {
            url: apiUrl + systemUrl + SystemEnum.ORG_DEL,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getUserOrgList: async (form, headers: any) => {
        const result: ResultDto<UserOrgRoleDto> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_GET_USER_ORG_LIST,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
};

OrgRoleApi = {
    list: async (form: string, headers: any) => {
        const result: ResultDto<SysOrgRoleEntity[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_LIST + "?orgId=" + form,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    selectPage: async (form: SysOrgRolePageForm, headers: any) => {
        const result: ResultDto<PageDto<SysOrgRoleEntity>> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    saveOrUpdate: async (form: SysOrgRoleEntity, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_SAVE_UPDATE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    delete: async (id: string[], headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(id, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_DEL,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getPermission: async (form: string, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_PERMISSION,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
};