import {WebClient} from "../../utils/WebClient";
import {apiUrl, SystemEnum, systemUrl} from "../../config/config";
import {ResultDto} from "../../model/ResultDto";
import {SysOrgDeptEntity} from "../../model/system/entity/SysOrgDeptEntity";
import {SysOrgDeptDto} from "../../model/system/dto/SysOrgDeptDto";
import {SysOrgDeptTeamEntity} from "../../model/system/entity/SysOrgDeptTeamEntity";
import {SysOrgDto} from "../../model/system/dto/SysOrgDto";
import {SaveSysDeptUserForm} from "../../model/system/form/SaveSysDeptUserForm";
import {UpdateSysDeptUserForm} from "../../model/system/form/UpdateSysDeptUserForm";
import {PageSysDeptUserForm} from "../../model/system/form/PageSysDeptUserForm";
import {SysOrgDeptUserDto} from "../../model/system/dto/SysOrgDeptUserDto";
import {PageSysDeptTeamUserForm} from "../../model/system/form/PageSysDeptTeamUserForm";
import {PageDto} from "../../model/PageDto";
import {ListSysDeptUserForm} from "../../model/system/form/ListSysDeptUserForm";
import {ListSysDeptTeamUserForm} from "../../model/system/form/ListSysDeptTeamUserForm";
import {PageSysOrgDeptTeamForm} from "../../model/system/form/PageSysOrgDeptTeamForm";

// tslint:disable-next-line:no-var-requires
const JsonBigString = require('json-bigint')({"storeAsString": true});

export let OrgDeptApi: OrgDeptInterface.dept;
export let OrgDeptTeamApi: OrgDeptTeamInterface.deptTeam;
export let OrgDeptUserApi: OrgDeptUserInterface.deptUser;

OrgDeptApi = {

    getDeptList: async (form: string, headers: any) => {
        const result: ResultDto<SysOrgDeptDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_LIST + "?orgId=" + form,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    list: async (form: string, headers: any) => {
        const result: ResultDto<SysOrgDeptDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_ORG_LIST + "?orgId=" + form,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    saveOrUpdate: async (form: SysOrgDeptEntity, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_SAVE_UPDATE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    selectOne: async (id: string, headers: any) => {
        const result: ResultDto<SysOrgDto> = JsonBigString.parse(await WebClient.requestDataToJson(id, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_ID + "/" + id,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
    delete: async (id: string[], headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(id, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_DEL,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
};

OrgDeptTeamApi = {
    delete: async (id: string[], headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(id, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_TEAM_DEL,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    selectPage: async (form: PageSysOrgDeptTeamForm, headers: any) => {
        const result = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_TEAM_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    saveOrUpdate: async (form: SysOrgDeptTeamEntity, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_TEAM_SAVE_UPDATE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    list: async (form: string, headers: any) => {
        const result: ResultDto<SysOrgDeptDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_TEAM_LIST + "?deptId=" + form,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
}
OrgDeptUserApi = {
    save: async (form: SaveSysDeptUserForm, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_USER_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    delete: async (id: string[], headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(id, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_USER_DEL,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    deptPage: async (form: PageSysDeptUserForm, headers: any) => {
        const result:ResultDto<PageDto<SysOrgDeptUserDto>> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_USER_DEPT_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    deptTeamPage: async (form: PageSysDeptTeamUserForm, headers: any) => {
        const result:ResultDto<PageDto<SysOrgDeptUserDto>> =  JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_USER_DEPT_TEAM_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    deptList: async (form: ListSysDeptUserForm, headers: any) => {
        const result:ResultDto<SysOrgDeptUserDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_USER_DEPT_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    teamList: async (form: ListSysDeptTeamUserForm, headers: any) => {
        const result:ResultDto<SysOrgDeptUserDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.OEG_DEPT_USER_DEPT_TEAM_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

}