import {WebClient} from "../../utils/WebClient";
import {apiUrl, SystemEnum, systemUrl} from "../../config/config";
import {ResultDto} from "../../model/ResultDto";
import {UpdateSysOrgUserForm} from "../../model/system/form/UpdateSysOrgUserForm";
import {SysOrgUserEntity} from "../../model/system/entity/SysOrgUserEntity";
import {PageDto} from "../../model/PageDto";
import {SysOrgUserPageDto} from "../../model/system/dto/SysOrgUserPageDto";
import {SysOrgRoleListForm} from "../../model/system/form/SysOrgRoleListForm";
import {SysOrgUserDto} from "../../model/system/dto/SysOrgUserDto";
import {SysOrgUserIdsForm} from "../../model/system/form/SysOrgUserIdsForm";
import {SysUserArcDto} from "../../model/system/dto/SysUserArcDto";
import {PageSysOrgRoleListForm} from "../../model/system/form/PageSysOrgRoleListForm";
import {UpdateSysOrgUserKeyFocusForm} from "../../model/system/form/UpdateSysOrgUserKeyFocusForm";
import {SaveSysOrgUserForm} from "../../model/system/form/SaveSysOrgUserForm";
import {PageSysOrgUserForm} from "../../model/system/form/PageSysOrgUserForm";
import {OrgUserPathForm} from "../../model/system/form/OrgUserPathForm";
import {PageOrgUserPathForm} from "../../model/system/form/PageOrgUserPathForm";
import {SysOrgRoleUserIdsForm} from "../../model/system/form/SysOrgRoleUserIdsForm";
import {SysUserArcRoleDto} from "../../model/system/dto/SysUserArcRoleDto";
import {SaveUserArcLogForm} from "../../model/user/form/SaveUserArcLogForm";
import {SysOrgEntity} from "../../model/system/entity/SysOrgEntity";

// tslint:disable-next-line:no-var-requires
const JsonBigString = require('json-bigint')({"storeAsString": true});

// @ts-ignore
export let OrgUserApi: OrgUserInterface.OrgUser;


OrgUserApi = {
    getOrgListByUserId: async (form: any, headers: any) => {
        const result: ResultDto<SysOrgUserEntity[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_LIST_USER_ID,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
    getOrgListByOrgRoleCode: async (form: SysOrgRoleListForm, headers: any) => {
        const result: ResultDto<SysOrgUserDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_LIST_ROLE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getOrgListByOrgRoleCodeUserIds: async (form: SysOrgRoleListForm, headers: any) => {
        const result: ResultDto<number[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_LIST_USER,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getOrgListByOrgRoleCodePage: async (form: PageSysOrgRoleListForm, headers: any) => {
        const result: ResultDto<SysOrgUserDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_LIST_ROLE_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getOrgListByOrgRoleCodeUserIdsPage: async (form: PageSysOrgRoleListForm, headers: any) => {
        const result: ResultDto<number[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_LIST_USER_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    getKeyOrgListByOrgRoleCodePage: async (form: PageSysOrgRoleListForm, headers: any) => {
        const result: ResultDto<SysOrgUserDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_KEY_USER_LIST_ROLE_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getKeyOrgListByOrgRoleCodeUserIdsPage: async (form: PageSysOrgRoleListForm, headers: any) => {
        const result: ResultDto<number[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_KEY_USER_LIST_USER_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    move: async (form: SaveUserArcLogForm, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ARC_MOVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getOrgByUser: async (form: string, headers: any) => {
        const result: ResultDto<SysOrgEntity> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ARC_GET_USER_ID+"?userId="+form,
            method: 'POST',
            headers: headers
        }));
        return result;
    },


    selectPage: async (form: PageSysOrgUserForm, headers: any) => {
        const result: ResultDto<PageDto<SysOrgUserPageDto>> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    selectOne: async (form: string, headers: any) => {
        const result: ResultDto<SysOrgUserPageDto> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_ID + "/" + form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
    getByUserIds: async (form: SysOrgUserIdsForm, headers: any) => {
        const result: ResultDto<SysUserArcDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_USER_IDS,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getUserArcRoleByUserIds: async (form: SysOrgRoleUserIdsForm, headers: any) => {
        const result: ResultDto<SysUserArcRoleDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_ROLE_USER_IDS,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    getCountByOrgId: async (form: string, roleCode: string, headers: any) => {
        const result: ResultDto<number> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_COUNT + "?orgId=" + form + "&roleCode=" + roleCode,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    save: async (form: SaveSysOrgUserForm, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    update: async (form: UpdateSysOrgUserForm, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_UPDATE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    updateKeyFocus: async (form: UpdateSysOrgUserKeyFocusForm, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_UPDATE_KEY,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    delete: async (id: string[], headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(id, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_DEL,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    selectUserPath: async (form: OrgUserPathForm, headers: any) => {
        const result: ResultDto<SysOrgUserDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_PATH,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    selectPageUserPath: async (form: PageOrgUserPathForm, headers: any) => {
        const result: ResultDto<PageDto<SysOrgUserDto>> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.ORG_ROLE_USER_PATH_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
};
