import {WebClient} from "../../utils/WebClient";
import {apiUrl, SystemEnum, systemUrl} from "../../config/config";
import {ResultDto} from "../../model/ResultDto";
import {ListMenuForm} from "../../model/system/form/ListMenuForm";
import {SysMenuEntity} from "../../model/system/entity/SysMenuEntity";
import {SysMenuDto} from "../../model/system/dto/SysMenuDto";
import {OrgPermissionForm} from "../../model/system/form/OrgPermissionForm";
import {PageDto} from "../../model/PageDto";

// tslint:disable-next-line:no-var-requires
const JsonBigString = require('json-bigint')({"storeAsString": true});

// @ts-ignore
export let SysMenuApi: SysMenuInterface.Menu;

SysMenuApi = {

    pageList: async (form: ListMenuForm, headers: any) => {
        const result: ResultDto<PageDto<SysMenuDto>> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    asyncList: async (form: string, headers: any) => {
        const result: ResultDto<SysMenuEntity[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_ASYNC_LIST,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
    saveOrUpdate: async (form: SysMenuEntity, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getSysMenu: async (form: SysMenuEntity, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_INFO,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
    delete: async (form: string, headers: any) => {
        const result: ResultDto<any> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_DELETE + "?ids=" + form,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    routes: async (form: string, headers: any) => {
        const result: ResultDto<SysMenuDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_ROUTES_LIST+"?id="+form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    routesMenu: async (form: string, headers: any) => {
        const result: ResultDto<SysMenuDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_ROUTES_MENU_LIST+"?id="+form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
    routesMenuButton: async (form: string, headers: any) => {
        const result: ResultDto<SysMenuDto[]> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_ROUTES_MENU_BUTTON_LIST+"?id="+form,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    roleMenuAdd: async (form: OrgPermissionForm, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_ROUTES_ROLE_ADD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    roleMenuDel: async (form: OrgPermissionForm, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_ROUTES_ROLE_DEL,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    loginSuccess: async (form: null, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(form, {
            url: apiUrl + systemUrl + SystemEnum.MENU_ROUTES_LOGIN,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
};
