import {WebClient} from "../../utils/WebClient";
import {ResultDto} from "../../model/ResultDto";
import {apiUrl, UserEnum, userUrl} from "../../config/config";
import {UserInfo} from "../../model/user/entity/UserInfo";
// @ts-ignore
import {UserArcPageDto} from "../../model/user/dto/UserArcPageDto";
import {PageDto} from "../../model/PageDto";
import {UserCardEntity} from "../../model/user/entity/UserCardEntity";
import {UserDiseaseEntity} from "../../model/user/entity/UserDiseaseEntity";
import {UserFamilyHisEntity} from "../../model/user/entity/UserFamilyHisEntity";
import {UserLiveEnvEntity} from "../../model/user/entity/UserLiveEnvEntity";
import {UserSurgeryHistEntity} from "../../model/user/entity/UserSurgeryHistEntity";
import {UserArcDto} from "../../model/user/form/UserArcDto";
import {SUCCESS} from "../../config/ResultCodeConfig";
import {UserSearchInfo} from "../../model/user/dto/UserSearchInfo";
import {UserKeyDiseaseDto} from "../../model/user/dto/UserKeyDiseaseDto";
import {UserEntity} from "../../model/user/entity/UserEntity";
import {UserArcLogEntity} from "../../model/user/entity/UserArcLogEntity";
import {IntegralConfigDto} from "../../model/user/dto/IntegralConfigDto";
import {IntegralDemotionDto} from "../../model/user/dto/IntegralDemotionDto";
import {IntegralGradeDto} from "../../model/user/dto/IntegralGradeDto";
import {IntegralGradeNextDto} from "../../model/user/dto/IntegralGradeNextDto";
import {IntegralLogDto} from "../../model/user/dto/IntegralLogDto";
import {SaveIntegralLogDto} from "../../model/user/dto/SaveIntegralLogDto";
import {UserIntegralEntity} from "../../model/user/entity/UserIntegralEntity";
// tslint:disable-next-line:no-var-requires
const JsonBigString = require('json-bigint')({"storeAsString": true});
// @ts-ignore
export let UserApi: UserInterface.user;
export let UserArcApi: UserInterface.userArc;
export let UserCardApi: UserInterface.userCard;
export let UserDiseaseApi: UserInterface.userDisease;
export let UserFamilyHisApi: UserInterface.userFamilyHis;
export let UserLiveEnvApi: UserInterface.userLiveEnv;
export let UserSurgeryHistApi: UserInterface.userSurgeryHist;
export let UserArcLogApi: UserInterface.userArcLog;
//健康币
export let IntegralConfigApi:UserInterface.integralConfig;
export let IntegralDemotion:UserInterface.integralDemotion;
export let IntegralGrade:UserInterface.integralGrade;
export let IntegralLog:UserInterface.integralLog;
export let UserIntegral:UserInterface.userIntegral;

UserApi = {
    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<UserEntity>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    reset: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_RESET + "?id=" + from,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    status: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_STATUS,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    icon: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ICON + "?icon=" + from,
            method: 'POST',
            headers: headers
        }));
        return result;
    },


    getUser: async (headers: any, errorCallback?: (message: string) => void) => {
        const result: ResultDto<UserInfo> = JsonBigString.parse(await WebClient.requestDataToJson(null, {
            url: apiUrl + userUrl + UserEnum.GET_USER,
            method: 'POST',
            headers: headers
        }));
        if (result.code != SUCCESS) {
            if (errorCallback != undefined) {
                errorCallback(result.msg);
            }
        }
        return result;
    },

    getUserByUserId: async (from, headers: any, errorCallback?: (message: string) => void) => {
        const result: ResultDto<UserInfo> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.GET_USER_BY_USER_ID + "?userId=" + from,
            method: 'POST',
            headers: headers
        }));
        if (result.code != SUCCESS) {
            if (errorCallback != undefined) {
                errorCallback(result.msg);
            }
        }
        return result;
    },

    getUserByIdCard: async (from, headers: any) => {
        const result: ResultDto<UserInfo> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.GET_USER_BY_ID_CARD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    getUserByAccount: async (from, headers: any) => {
        const result: ResultDto<UserInfo> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.GET_USER_BY_ACCOUNT + "?accountName=" + from,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    search: async (from, headers: any) => {
        const result: ResultDto<UserSearchInfo[]> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.GET_USER_SEARCH + "?key=" + from,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    userIds: async (from, headers: any) => {
        const result: ResultDto<UserSearchInfo[]> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.GET_USER_IDS,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
};

UserArcApi = {

    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<UserArcPageDto>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ARC_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    getById: async (from, headers: any) => {
        const result: ResultDto<UserArcDto> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ARC_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    getByUserId: async (from: string, headers: any) => {
        const result: ResultDto<UserArcDto> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ARC_USER_ID + "?userId=" + from,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    upd: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ARC_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    updByUserId: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ARC_USER_ID_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },


    save: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ARC_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },


    status: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ARC_STATUS,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
}

UserCardApi = {

    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<UserCardEntity>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_CARD_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    getUserCardListByUserId: async (from, headers: any) => {
        const result: ResultDto<UserCardEntity[]> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_CARD_GET_LIST_BY_USER_ID + "?userId=" + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    getById: async (from, headers: any) => {
        const result: ResultDto<UserCardEntity> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_CARD_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    save: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_CARD_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    upd: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_CARD_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    del: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_CARD_DEL_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
    //身份证识别
    idCard: async (from, headers: any) => {
        const result: ResultDto<object> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_CARD_ID_CARD + "?imagePara=" + from,
            method: 'GET',
            headers: {
                'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
                'Accept-Encoding': 'gzip, deflate',
                'Accept-Language': 'zh-CN,zh;q=0.9'
            }
        }));
        return result;
    },
    //身份证识别base64
    idCardBase64: async (from, headers: any) => {
        const result: ResultDto<object> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_CARD_ID_CARD_BASE64 + "?imagePara=" + from,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
}

UserDiseaseApi = {

    getUserKeyDisease: async (from, headers: any) => {
        const result: ResultDto<UserKeyDiseaseDto> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_DISEASE_KEY + "?userId=" + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<UserDiseaseEntity>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_DISEASE_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    getUserDiseaseListByUserId: async (from, headers: any) => {
        const result: ResultDto<UserDiseaseEntity[]> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_DISEASE_GET_LIST_BY_USER_ID + "?userId=" + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    getById: async (from, headers: any) => {
        const result: ResultDto<UserDiseaseEntity> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_DISEASE_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    save: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_DISEASE_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    upd: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_DISEASE_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    del: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_DISEASE_DEL_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
}

UserFamilyHisApi = {
    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<UserFamilyHisEntity>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_FAMILY_HIS_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    getUserFamilyHisListByUserId: async (from, headers: any) => {
        const result: ResultDto<UserFamilyHisEntity[]> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_FAMILY_HIS_GET_LIST_BY_USER_ID + "?userId=" + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    getById: async (from, headers: any) => {
        const result: ResultDto<UserFamilyHisEntity> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_FAMILY_HIS_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    save: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_FAMILY_HIS_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    upd: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_FAMILY_HIS_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    del: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_FAMILY_HIS_DEL_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
}

UserLiveEnvApi = {

    getUserLiveEnvListByUserId: async (from, headers: any) => {
        const result: ResultDto<UserLiveEnvEntity[]> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_LIVE_ENV_GET_LIST_BY_USER_ID + "?userId=" + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    getById: async (from, headers: any) => {
        const result: ResultDto<UserLiveEnvEntity> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_LIVE_ENV_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    save: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_LIVE_ENV_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    upd: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_LIVE_ENV_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    del: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_LIVE_ENV_DEL_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
}

UserSurgeryHistApi = {
    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<UserSurgeryHistEntity>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_SURGERY_HIST_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    getUserSurgeryHistListByUserId: async (from, headers: any) => {
        const result: ResultDto<UserSurgeryHistEntity[]> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_SURGERY_HIST_GET_LIST_BY_USER_ID + "?userId=" + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    getById: async (from, headers: any) => {
        const result: ResultDto<UserSurgeryHistEntity> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_SURGERY_HIST_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    save: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_SURGERY_HIST_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    upd: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_SURGERY_HIST_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    del: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_SURGERY_HIST_DEL_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
}

/**
 * 用户档案操作日志
 */
UserArcLogApi = {
    getById: async (from, headers: any) => {
        const result: ResultDto<UserArcLogEntity> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ARC_LOG_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<UserArcLogEntity>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ARC_LOG_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    list: async (from, headers: any) => {
        const result: ResultDto<UserArcLogEntity[]> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.USER_ARC_LOG_LIST,
            method: 'POST',
            headers: headers
        }));
        return result;
    }
}
IntegralConfigApi = {
    getById: async (from, headers: any) => {
        const result: ResultDto<IntegralConfigDto> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_CONFIG_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<IntegralConfigDto>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_CONFIG_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    save: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_CONFIG_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    upd: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_CONFIG_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    del: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_CONFIG_DEL ,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
}
//降级配置
IntegralDemotion={
    getById: async (from, headers: any) => {
        const result: ResultDto<IntegralDemotionDto> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_DEMOTION_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<IntegralDemotionDto>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_DEMOTION_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    save: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_DEMOTION_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    upd: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_DEMOTION_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    del: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_DEMOTION_DEL ,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
}
//等级配置
IntegralGrade={
    getList: async ( headers: any) => {
        const result: ResultDto<IntegralGradeDto> = JsonBigString.parse(await WebClient.requestDataToJson("", {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_LIST_ID ,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
    nextCycle: async ( from,headers: any) => {
        const result: ResultDto<IntegralGradeNextDto> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_NEXTCYCLE_ID ,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getById: async (from, headers: any) => {
        const result: ResultDto<IntegralGradeDto> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_GRADE_ID + from,
            method: 'GET',
            headers: headers
        }));
        return result;
    },

    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<IntegralGradeDto>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_GRADE_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    save: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_GRADE_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    upd: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_GRADE_UPD,
            method: 'POST',
            headers: headers
        }));
        return result;
    },

    del: async (from, headers: any) => {
        const result: ResultDto<boolean> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_GRADE_DEL,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
}
//健康币记录
IntegralLog= {
    page: async (from, headers: any) => {
        const result: ResultDto<PageDto<IntegralLogDto>> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_LOG_PAGE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    save: async (from, headers: any) => {
        const result: ResultDto<SaveIntegralLogDto> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_LOG_SAVE,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
    getDayIntegral: async (from, headers: any) => {
        const result: ResultDto<SaveIntegralLogDto> = JsonBigString.parse(await WebClient.requestDataToJson(from, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_LOG_DAY,
            method: 'POST',
            headers: headers
        }));
        return result;
    },
}
//用户当前类型等级
UserIntegral= {
    getById: async (userId,event, headers: any) => {
        const result: ResultDto<UserIntegralEntity> = JsonBigString.parse(await WebClient.requestDataToJson(userId, {
            url: apiUrl + userUrl + UserEnum.INTEGRAL_GRADE_ONE + "?userId="+userId+"&event="+event,
            method: 'GET',
            headers: headers
        }));
        return result;
    },
}