import * as request from 'request';
import {apiUrl } from "../config/config";
import {ResultDto} from "../model/ResultDto";
import axios from 'axios';

export enum HttpMethod {
    POST= "POST",
    GET = "GET",
    PUT = "PUT",
    PATCH = "PATCH",
    DELETE="DELETE",
    COPY="COPY",
    HEAD="HEAD",
    OPTIONS="OPTIONS",
    LINK="LINK",
    UNLINK="UNLINK",
    PURGE="PURGE",
    LOCK="LOCK",
    UNLOCK="UNLOCK",
    PROPFIND="PROPFIND",
    VIEW="VIEW"
}

// tslint:disable-next-line:no-var-requires
const JSON = require('json-bigint')({"storeAsString": true})
export class WebClient {

    private constructor() {

    };

    public static async request(data: any, options: request.Options): Promise<any> {
        // @ts-ignore
        const contentBuf =Buffer.from(data);
        options.headers['Content-Length'] = contentBuf.byteLength;
        return await WebClient.httpRequest(contentBuf, options);
    };

    public static async requestDataToJson(data: any, options: request.Options): Promise<any> {
        // @ts-ignore
        const contentBuf = Buffer.from(JSON.stringify(data));
        options.headers['Content-Length'] = contentBuf.byteLength;
        return await WebClient.httpRequest(contentBuf, options);
    };

    public static async requestTwoData(data: any,data2:any ,options: request.Options): Promise<any> {
        // @ts-ignore
        const contentBuf = Buffer.from(JSON.stringify(data));
        options.headers['Content-Length'] = contentBuf.byteLength;
        return await WebClient.httpRequest(contentBuf,options);
    };

    public static generateOption(url:string,method:HttpMethod,headers:any) :
        request.Options {
        return {
            url: apiUrl + url,
            method: method,
            headers: headers
        }
    }

    public static async requestResultDto(data: any, url:string,method:HttpMethod,headers:any):
        Promise<ResultDto<any>> {
        const options = WebClient.generateOption(url,method,headers);
        // @ts-ignore
        const contentBuf =Buffer.from(JSON.stringify(data));
        options.headers['Content-Length'] = contentBuf.byteLength;
        return JSON.parse(await WebClient.httpRequest(contentBuf, options));
    };

    public static async requestResultDtoPost(data: any, url:string,headers:any):
        Promise<ResultDto<any>> {
        return await WebClient.requestResultDto(data,url,HttpMethod.POST, headers);
    };

    public static async requestResultDtoGet(data: any, url:string,headers:any):
        Promise<ResultDto<any>> {
        return await WebClient.requestResultDto(data,url,HttpMethod.GET, headers);
    };

    private static async httpRequest(content: Buffer,
                                     options: request.Options) {
        let isCalled = false;
        return new Promise((resolve, reject) => {
            const req = request(options, (err, res, body) => {
                if (isCalled) {
                    return console.error(null, "多次调用");
                }
                isCalled = true;
                if (err) {
                    throw new Error(err); 
                    reject(err);
                }
                const msgs =JSON.parse(body) ;
                resolve(body)
                if(msgs.code!=200){
                    throw new Error(msgs.code); 
                }
            });
            req.write(content);
            req.end();
        });
    }
    public static async httpAxios(url:string,data:any):Promise<ResultDto<any>> {
        let isCalled = false;
        return new Promise((resolve, reject) => {
            const req =axios.post(url,data).then((res:any)=>{
                if (isCalled) {
                    return console.error(null, "多次调用");
                }
                isCalled = true;
                resolve(res.data);
                if(res.data.code!=200){
                    throw new Error(res.data.code); 
                }
            }).catch((err:any)=>{
                reject(err);
                throw new Error(err);  
            })
        });
    }

    public static async httpGetAxios(url:string,data:any):Promise<ResultDto<any>> {
        let isCalled = false;
        return new Promise((resolve, reject) => {
            const req =axios.get(url,data).then((res:any)=>{
                if (isCalled) {
                    return console.error(null, "多次调用");
                }
                isCalled = true;
                resolve(res.data);
                if(res.data.code!=200){
                    throw new Error(res.data.code); 
                }
            }).catch((err:any)=>{
                reject(err);
                throw new Error(err);
            })
        });
    }
}
